===============
Toolkit Library
===============


|

Introduction
************
Tookit Library is a collection of python modules for general purpose usage.

It's a supplementary to the standard python library.


|

Quick Start
***********

::

    pip install toolkit_library    


|

Modules included
****************

::


    toolkit_library.encryption
    ~~~~~~~~~~~~~~~~~~~~~~~~~~
    Generate random salt, hashcode for a password and validate the password against them.


    toolkit_library.input_util
    ~~~~~~~~~~~~~~~~~~~~~~~~~~
    Get inputs from user and validate them 


    toolkit_library.inspector
    ~~~~~~~~~~~~~~~~~~~~~~~~~
    Inspect a module or a package, get information of modules, methods and classes.


    toolkit_library.mail_server
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~
    Connect to a SMTP server and send email


    toolkit_library.string_util
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~
    Utilities to deal with strings


    toolkit_library.text_converter
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    Convert text from one format to another


    toolkit_library.web_client
    ~~~~~~~~~~~~~~~~~~~~~~~~~~
    Web client for fetching web resources.              


|

You wanna involve? 
******************
toolkit_library is released under BSD lisence.

The source code is hosted on github: https://github.com/tylerlong/toolkit_library


|

Feedback
********
Comments, suggestions, questions, free beer, t-shirts, kindles, ipads ... are all welcome!

Email: toolkit.library.feedback@gmail.com
